Connect to the BirdWeather API
connect_birdweather.RdEstablishes a connection to the BirdWeather GraphQL API. Must be called once per session before using any other package functions.
connect_birdweather.RdEstablishes a connection to the BirdWeather GraphQL API. Must be called once per session before using any other package functions.