Skip to contents

BirdWeather PUC detections across stations in the path of the April 8, 2024 total solar eclipse in North America, filtered to confidence >= 0.6.

Usage

total_eclipse

Format

A data.table with detection and station columns as returned by get_detections()

BirdWeather API via birdweatheR